@@ -1,6 +1,6 @@
 package Pcore::AppX::H;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 with qw[Pcore::AppX];
 
