@@ -1,11 +1,9 @@
 package Pcore::Dist::CLI::Info;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 with qw[Pcore::Dist::CLI];
 
-no Pcore;
-
 sub cli_abstract ($self) {
     return 'show different distribution info';
 }
@@ -32,7 +30,7 @@ share_dir: <: $dist.share_dir :>
 lib_dir: <: $dist.module.lib :>
 TMPL
 
-    say P->tmpl->render( \$tmpl, { dist => $pcore ? $PROC->pcore : $self->dist } )->$*;
+    say P->tmpl->render( \$tmpl, { dist => $pcore ? $ENV->pcore : $self->dist } )->$*;
 
     return;
 }
