@@ -1,25 +1,13 @@
 package Pcore::Util::Date;
 
 use Pcore;
+use base qw[Time::Moment];
 use HTTP::Date qw[];
 use Time::Zone qw[];
-use Time::Moment qw[];
-
-no Pcore;
-
-for my $sub (qw[new now now_utc from_epoch from_object from_string]) {
-    no strict qw[refs];
-
-    *{ 'Pcore::Util::Date::' . $sub } = sub {
-        my $self = shift;
-
-        return Time::Moment->$sub(@_);
-    };
-}
 
 sub parse ( $self, $date ) {
     if ( my @http_date = HTTP::Date::parse_date($date) ) {
-        return Time::Moment->new(
+        return $self->new(
             year       => $http_date[0],
             month      => $http_date[1],
             day        => $http_date[2],
@@ -35,20 +23,16 @@ sub parse ( $self, $date ) {
     }
 }
 
-{
-    no strict qw[refs];
+sub to_rfc_1123 ($self) {
+    return $self->strftime('%a, %d %b %Y %H:%M:%S %z');
+}
 
-    *{'Time::Moment::to_rfc_1123'} = sub {
-        return $_[0]->strftime('%a, %d %b %Y %H:%M:%S %z');
-    };
+sub to_rfc_2616 ($self) {
+    return $self->at_utc->strftime('%a, %d %b %Y %H:%M:%S GMT');
+}
 
-    *{'Time::Moment::to_rfc_2616'} = sub {
-        return $_[0]->at_utc->strftime('%a, %d %b %Y %H:%M:%S GMT');
-    };
-
-    *{'Time::Moment::to_http_date'} = sub {
-        return $_[0]->at_utc->strftime('%a, %d %b %Y %H:%M:%S GMT');
-    };
+sub to_http_date ($self) {
+    return $self->at_utc->strftime('%a, %d %b %Y %H:%M:%S GMT');
 }
 
 1;
