@@ -1,11 +1,9 @@
 package Pcore::Util::URI::file;    ## no critic qw[NamingConventions::Capitalization]
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::Util::URI];
 
-no Pcore;
-
 1;
 __END__
 =pod
